==> open-xchange-core_7.10.0.orig.tar.bz2: open-xchange-core-7.10.0/com.openexchange.server/src/com/openexchange/webdav/action/WebdavExistsAction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.webdav.action;

import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import com.openexchange.webdav.protocol.WebdavProtocolException;

public class WebdavExistsAction extends AbstractAction {
    private boolean tolerateLockNull = false;

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(WebdavExistsAction.class);

    private static final String NOT_FOUND = "There is nothing here, sorry.";

    @Override
	public void perform(final WebdavRequest req, final WebdavResponse res) throws WebdavProtocolException {
		if(!req.getResource().exists()) {
		    notFound(req, res);
        }
        if(req.getResource().isLockNull() && !tolerateLockNull) {
            notFound(req, res);
        }
        yield(req,res);
	}

    private void notFound(final WebdavRequest req, final WebdavResponse res) throws WebdavProtocolException {
        try {
            res.sendString(NOT_FOUND);
        } catch (final IOException e) {
            LOG.debug("Client gone?", e);
        }
        throw WebdavProtocolException.Code.GENERAL_ERROR.create(req.getUrl(), HttpServletResponse.SC_NOT_FOUND);
    }

    public void setTolerateLockNull(final boolean b) {
        tolerateLockNull = b;
    }
}

==> open-xchange-core_7.10.3.orig.tar.bz2: open-xchange-core-7.10.3/com.openexchange.server/src/com/openexchange/webdav/action/WebdavExistsAction.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.webdav.action;

import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import com.openexchange.webdav.protocol.WebdavProtocolException;

public class WebdavExistsAction extends AbstractAction {
    private boolean tolerateLockNull = false;

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(WebdavExistsAction.class);

    private static final String NOT_FOUND = "There is nothing here, sorry.";

    @Override
	public void perform(final WebdavRequest req, final WebdavResponse res) throws WebdavProtocolException {
		if (!req.getResource().exists()) {
		    notFound(req, res);
        }
        if (req.getResource().isLockNull() && !tolerateLockNull) {
            notFound(req, res);
        }
        yield(req,res);
	}

    private void notFound(final WebdavRequest req, final WebdavResponse res) throws WebdavProtocolException {
        try {
            res.sendString(NOT_FOUND);
        } catch (IOException e) {
            LOG.debug("Client gone?", e);
        }
        throw WebdavProtocolException.Code.GENERAL_ERROR.create(req.getUrl(), HttpServletResponse.SC_NOT_FOUND);
    }

    public void setTolerateLockNull(final boolean b) {
        tolerateLockNull = b;
    }
}
